@@ -51,9 +51,10 @@ _start_args = {
     'disable_cache': True,                          # Sets the no-store response header when serving assets
     'default_path': 'index.html',                   # The default file to retrieve for the root URL
     'app': btl.default_app(),                       # Allows passing in a custom Bottle instance, e.g. with middleware
+    'shutdown_delay': 1.0                          # how long to wait after a websocket closes before detecting complete shutdown
 }
 
-# == Temporary (suppressable) error message to inform users of breaking API change for v1.0.0 ===
+# == Temporary (suppressible) error message to inform users of breaking API change for v1.0.0 ===
 _start_args['suppress_error'] = False
 api_error_message = '''
 ----------------------------------------------------------------------------------
@@ -153,6 +154,10 @@ def start(*start_urls, **kwargs):
         _start_args['jinja_env'] = Environment(loader=FileSystemLoader(templates_path),
                                  autoescape=select_autoescape(['html', 'xml']))
 
+    # verify shutdown_delay is correct value
+    if not isinstance(_start_args['shutdown_delay'], (int, float)):
+        raise ValueError("`shutdown_delay` must be a number, "\
+            "got a {}".format(type(_start_args['shutdown_delay'])))
 
     # Launch the browser to the starting URLs
     show(*start_urls)
@@ -380,7 +385,7 @@ def _websocket_close(page):
         if _shutdown:
             _shutdown.kill()
 
-        _shutdown = gvt.spawn_later(1.0, _detect_shutdown)
+        _shutdown = gvt.spawn_later(_start_args['shutdown_delay'], _detect_shutdown)
 
 
 def _set_response_headers(response):
